@@ -160,6 +160,11 @@ group_designation <- function(omicsData,
     if (sum(main_effects %in% names(omicsData$f_data)) != length(main_effects)) {
       stop("One or more of the main_effects is not found in f_data of omicsData")
     }
+    
+    # Remove names if named vector
+    if(length(names(main_effects)) > 0){
+      names(main_effects) <- NULL
+    }
   }
 
   # Check covariates ---------------
